//NTP TZ DST - bare minimum
//  NetWork Time Protocol - Time Zone - Daylight Saving Time
//
//  Our target for this MINI sketch is:
//  - get the SNTP request running
//  - set the timezone
//  - (implicit) respect daylight saving time
//  - how to "read" time to be printed to Serial.Monitor
//
//  This example is a stripped down version of the NTP-TZ-DST (v2)
//  And works for ESP8266 core 2.7.4
//
//  by noiasca
//  2020-09-22
//*/

#ifndef STASSID
#define STASSID "MIWIFI_2G_4E4H"                            // set your SSID
#define STAPSK  "YaM7rPuc"                        // set your wifi password
#endif

// neopixels: pin number & pixel count.
const int neo = D6; // Pin where NeoPixels are connected 12
const int pixel_count = 8; // number of neopixels



// radarmotionsensor: pin number & detection flag.
const int motion = D7;
int flg = 0;  //Change detection flag
/* Configuration of NTP */
#define MY_NTP_SERVER "europe.pool.ntp.org"
#define MY_TZ "CET-1CEST,M3.5.0/02,M10.5.0/03"


/* Necessary Includes */
#include <ESP8266WiFi.h>            // we need wifi to get internet access
#include <time.h>                   // time() ctime()
#include <moonPhaser.h>;     
#include <Adafruit_NeoPixel.h>// moonphase for esp8266


Adafruit_NeoPixel strip = Adafruit_NeoPixel(neo, pixel_count, NEO_GRB + NEO_KHZ800);

// moon phase: include a MoonPhase instance
moonPhaser moonPhase;

// moon phase: variable to receive the data
moonData_t moon;

/* Globals */
time_t now;                         // this is the epoch
tm tm;


int32_t currentYear = tm.tm_year + 1900;
int32_t currentMonth = tm.tm_mon + 1;
int32_t monthDay = tm.tm_mday;
double currentHour = tm.tm_hour;



// the structure tm holds time information in a more convient way
void showTime() {
  time(&now);                       // read the current time
  localtime_r(&now, &tm);           // update the structure tm with the current time
  Serial.print("year:");
  Serial.print(tm.tm_year + 1900);  // years since 1900
  Serial.print("\tmonth:");
  Serial.print(tm.tm_mon + 1);      // January = 0 (!)
  Serial.print("\tday:");
  Serial.print(tm.tm_mday);         // day of month
  Serial.print("\thour:");
  Serial.print(tm.tm_hour);         // hours since midnight  0-23
  Serial.print("\tmin:");
  Serial.print(tm.tm_min);          // minutes after the hour  0-59
  Serial.print("\tsec:");
  Serial.print(tm.tm_sec);          // seconds after the minute  0-61*
  Serial.print("\twday");
  Serial.print(tm.tm_wday);         // days since Sunday 0-6
  if (tm.tm_isdst == 1)             // Daylight Saving Time flag
    Serial.print("\tDST");
  else
    Serial.print("\tstandard");
  Serial.println();

  moon = moonPhase.getPhase(currentYear, currentMonth, monthDay, currentHour);
  // Waxing: 0-180
  // Waning: 180-360
  Serial.print( "Moon angle: " );
  Serial.print( moon.angle );             // moon.angle is a integer between 0-360
  Serial.println( " degrees." );
  Serial.print( "Moon surface lit: " );
  Serial.println( moon.percentLit * 100 );  // value is between 0 & 1

  if (((0 <= moon.angle) && (moon.angle < 1)) || ((359 < moon.angle) && (moon.angle <= 360))) {
    //    newmoon();
    Serial.println("newmoon");
  } else if ((1 <= moon.angle) && ( moon.angle < 90)) {
    //    waxingcrescent();
    Serial.println("waxingcrescent");
    
  } else if ((89 < moon.angle) && (moon.angle <= 90)) {
    //    firstquarter();
    Serial.println("firstquarter");
    
  } else if ((90 < moon.angle) && (moon.angle <= 179)) {
    //    waxinggibbous();
    Serial.println("waxinggibbous");
    
  } else if ((179 < moon.angle) && (moon.angle <= 180)) {
    //    fullmoon();
    Serial.println("fullmoon");
    
  } else if ((180 < moon.angle) && (moon.angle < 269)) {
    //    waninggibbous();
    Serial.println("waninggibbous");
    
  }  else if ((271 < moon.angle) && (moon.angle < 359)) {
    //    waningcrescent ();
    Serial.println("waningcrescent");
  } else if ((269 <= moon.angle) && (moon.angle <= 270)) {
    //    thirdquarter();
    Serial.println("thirdquarter");
  } 

}



//void waxingcrescent(){
//  strip.setPixelColor(0, 255, 0, 0);
//  strip.setPixelColor(0, 255, 0, 0); 
//  strip.setPixelColor(0, 255, 0, 0); 
//  strip.setPixelColor(0, 255, 0, 0); //
//  strip.show(); //Show The Color
//  delay(1000);
//};
//
//void firstquarter(){
//  
//};
//
//void waxinggibbous(){
//  
//};
//
//void fullmoon(){
//
//};
//


void setup() {
  Serial.begin(115200);

  
  Serial.println("\nNTP TZ DST - bare minimum");
  configTime(MY_TZ, MY_NTP_SERVER); // --> Here is the IMPORTANT ONE LINER needed in your sketch!


  // start network
  WiFi.persistent(false);
  WiFi.mode(WIFI_STA);
  WiFi.begin(STASSID, STAPSK);
  while (WiFi.status() != WL_CONNECTED) {
    delay(200);
    Serial.print ( "." );
  }
  Serial.println("WiFi connected");
  // by default, the NTP will be started after 60 secs

//
//  strip.begin();
//  strip.show();  // Initialize all pixels to 'off'


 
//  pinMode (motion, INPUT);  //motion as INPUT
//  pinMode (neo, OUTPUT);    //Neo as OUTPUT
}

void loop() {

  showTime();
  delay(3000);
}
