

// Libraries
#include <FastLED.h>                 // Adafruit strip.begin() was clashing with wifi.
#include <ESP8266WiFi.h>            // we need wifi to get internet access
#include <time.h>                   // time() ctime()
#include <moonPhaser.h>;            // our lovely moon
#include <ESP_EEPROM.h>


// Auxiliar variables to store the current output state
String output5State = "off";

// Assign output variables to GPIO pins
const int output5 = D1;

// Wifi credentials
#ifndef STASSID
//#define STASSID "MIWIFI_2G_4E4H"                            // set your SSID
//#define STAPSK  "YaM7rPuc"                        // set your wifi password
#define STASSID "Iaac-Wifi"                            // set your SSID
#define STAPSK  "enteriaac2013"                        // set your wifi password
#endif


// FASTLED;
// pin number of data communication, amount of leds, the chipset, the color order.
#define LED_PIN 4
#define NUM_LEDS    94
#define CHIPSET     WS2811
#define COLOR_ORDER GRB
CRGB leds[NUM_LEDS];


// All stuff for local server

// Set web server port number to 80
WiFiServer server(80);

// Variable to store the HTTP request
String header;

// Auxiliar variables to store the current output state
String button = "still counting"; //still counting days until period.


// radarmotionsensor: pin number & detection flag.
const int motion = 5;
int sensorVal = 0;


/* Configuration of NTP */
#define MY_NTP_SERVER "europe.pool.ntp.org"
#define MY_TZ "CET-1CEST,M3.5.0/02,M10.5.0/03"


// moon phase: include a MoonPhase instance
moonPhaser moonPhase;

// moon phase: variable to receive the data
moonData_t moon;

/* Globals */
time_t now;                         // this is the epoch
tm tm;


// Current time
unsigned long currentTime = millis();
// Previous time
unsigned long previousTime = 0;
// Define timeout time in milliseconds (example: 2000ms = 2s)
const long timeoutTime = 2000;

// Motion sensor
unsigned long previousMillis = 0; // long to keep the lamp on for 5 mins // do these two affect each other?
unsigned long currentMillis = 0;

bool light = false;

unsigned long aNewVar3;


void showTime() {                     // the structure tm holds time information in a more convient way

  time(&now);                       // read the current time
  delay(20);
  localtime_r(&now, &tm);           // update the structure tm with the current time
  Serial.println("year:");
  Serial.println(tm.tm_year + 1900);  // years since 1900
  Serial.println("\tmonth:");
  Serial.println(tm.tm_mon + 1);      // January = 0 (!)
  Serial.println("\tday:");
  Serial.println(tm.tm_mday);         // day of month
  Serial.println("\thour:");
  Serial.println(tm.tm_hour);         // hours since midnight  0-23
  Serial.println("\tmin:");
  Serial.println(tm.tm_min);          // minutes after the hour  0-59
  Serial.println("\tsec:");
  Serial.println(tm.tm_sec);          // seconds after the minute  0-61*
  Serial.println("\twday");
  Serial.println(tm.tm_wday);         // days since Sunday 0-6


  if (tm.tm_isdst == 1)             // Daylight Saving Time flag
    Serial.println("\tDST");
  else
    Serial.println ("\tstandard");
  Serial.println();
  delay(20);



  int32_t currentYear = tm.tm_year + 1900;
  int32_t currentMonth = tm.tm_mon + 1;
  int32_t monthDay = tm.tm_mday;
  double currentHour = tm.tm_hour;


  moon = moonPhase.getPhase(currentYear, currentMonth, monthDay, currentHour);
  // Waxing: 0-180
  // Waning: 180-360
  Serial.print( "Moon angle: " );
  Serial.print( moon.angle );             // moon.angle is a integer between 0-360
  Serial.println( " degrees." );
  Serial.print( "Moon surface lit: " );
  Serial.println( moon.percentLit * 100 );  // value is between 0 & 1};

}




void setup() {
  Serial.begin(115200);
  EEPROM.begin(64);
  delay(300);
  FastLED.addLeds<CHIPSET, LED_PIN, COLOR_ORDER>(leds, NUM_LEDS).setCorrection( TypicalSMD5050 );

  //
  Serial.println("\nNTP TZ DST - bare minimum");
  configTime(MY_TZ, MY_NTP_SERVER); // --> Here is the IMPORTANT ONE LINER needed in your sketch!

  // Start network
  WiFi.persistent(false);
  WiFi.mode(WIFI_STA);
  WiFi.begin(STASSID, STAPSK);
  while (WiFi.status() != WL_CONNECTED) {
    delay(200);
    Serial.print ( "." );
  }
  Serial.println("");
  Serial.println("WiFi connected.");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());
  server.begin();
  //  pinMode (motion, INPUT);  // RCWL-0516 output is input for Nano

  EEPROM.get(0, aNewVar3);
  aNewVar3 += 2160000;
  Serial.println("button+25");
  Serial.println((aNewVar3));
}



void loop() {

  WiFiClient client = server.available();   // Listen for incoming clients

  if (client) {                             // If a new client connects,
    Serial.println("New Client.");          // print a message out in the serial port
    String currentLine = "";                // make a String to hold incoming data from the client
    currentTime = millis();
    previousTime = currentTime;
    while (client.connected() && currentTime - previousTime <= timeoutTime) { // loop while the client's connected
      currentTime = millis();
      if (client.available()) {             // if there's bytes to read from the client,
        char c = client.read();             // read a byte, then
        Serial.write(c);                    // print it out the serial monitor
        header += c;
        if (c == '\n') {                    // if the byte is a newline character
          // if the current line is blank, you got two newline characters in a row.
          // that's the end of the client HTTP request, so send a response:
          if (currentLine.length() == 0) {
            // HTTP headers always start with a response code (e.g. HTTP/1.1 200 OK)
            // and a content-type so the client knows what's coming, then a blank line:
            client.println("HTTP/1.1 200 OK");
            client.println("Content-type:text/html");
            client.println("Connection: close");
            client.println();

            // turns the GPIOs on and off
            if (header.indexOf("GET /YAS I CAN!") >= 0) {
              Serial.println("Start counting 25 days");

              output5State = "on";
              digitalWrite(output5, HIGH);
            } else if (header.indexOf("GET /") >= 0) {
              output5State = "off";
              { unsigned long aNewVar1 = time(&now);
                EEPROM.put(0, aNewVar1);
                boolean ok1 = EEPROM.commit();
                Serial.println((ok1) ? "First commit OK" : "Commit failed");

                // this goes where the epoch
                //unsigned long aNewVar2;
                EEPROM.get(0, aNewVar3);
                aNewVar3 += 2160000;
                Serial.print("Read back the time of your period + 25 days from EEPROM: ");
                Serial.println(aNewVar3);

              }
              digitalWrite(output5, LOW);
            }


            // Display the HTML web page
            client.println("<!DOCTYPE html><html>");
            client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");
            client.println("<link rel=\"icon\" href=\"data:,\">");
            // CSS to style the on/off buttons
            // Feel free to change the background-color and font-size attributes to fit your preferences
            client.println("<style>html { font-family: Helvetica; display: inline-block; margin: 0px auto; text-align: center;}");
            client.println(".button { background-color: #195B6A; border: none; color: white; padding: 16px 40px;");
            client.println("text-decoration: none; font-size: 30px; margin: 2px; cursor: pointer;}");
            client.println(".button2 {background-color: #77878A;}</style></head>");


            // Web Page Heading
            client.println("<body><h1>Can you please already?</h1>");

            // Display current state, and ON/OFF buttons for GPIO 5
            client.println("<p>GPIO 5 - State " + output5State + "</p>");
            // If the output5State is off, it displays the ON button
            if (output5State == "off") {
              client.println("<p><a href=\"/5/on\"><button class=\"button\">ON</button></a></p>");
            } else {
              client.println("<p><a href=\"/5/off\"><button class=\"button button2\">OFF</button></a></p>");
            }

            // The HTTP response ends with another blank line
            client.println();
            // Break out of the while loop
            break;
          } else { // if you got a newline, then clear currentLine
            currentLine = "";
          }
        } else if (c != '\r') {  // if you got anything else but a carriage return character,
          currentLine += c;      // add it to the end of the currentLine
        }
      }
    }
    // Clear the header variable
    header = "";
    // Close the connection
    client.stop();
    Serial.println("Client disconnected.");
    Serial.println("");
  }
  if ((aNewVar3) < time(&now)) {
    for (int i = 0; i < NUM_LEDS; i++) {
      leds[i] = CRGB::Orange;
      Serial.println("PMS TIME");
    }
    FastLED.show();
    Serial.println ("alllightson40");
    FastLED.clear();
  }
  else {
    for (int i = 0; i < NUM_LEDS; i++) {
      leds[i] = CRGB::Blue;
      //Serial.println("OFF");
    }
    FastLED.show();
    Serial.println ("OFFF");
    FastLED.clear();
  }
}
